X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/d3ca495e61e0e9d66095b1aba2fd1995e564e841..5c418d269304af618b142e0328742fc7d7157c62:/IkiWiki/Plugin/attachment.pm
diff --git a/IkiWiki/Plugin/attachment.pm b/IkiWiki/Plugin/attachment.pm
index dcac3e820..44781165c 100644
--- a/IkiWiki/Plugin/attachment.pm
+++ b/IkiWiki/Plugin/attachment.pm
@@ -6,6 +6,7 @@ use strict;
use IkiWiki 2.00;
sub import { #{{{
+ add_underlay("javascript");
hook(type => "getsetup", id => "attachment", call => \&getsetup);
hook(type => "checkconfig", id => "attachment", call => \&checkconfig);
hook(type => "formbuilder_setup", id => "attachment", call => \&formbuilder_setup);
@@ -104,10 +105,10 @@ sub formbuilder_setup (@) { #{{{
$form->tmpl_param("field-upload" => '');
$form->tmpl_param("field-link" => '');
# Add the javascript from the toggle plugin;
# the attachments interface uses it to toggle visibility.
require IkiWiki::Plugin::toggle;
- $form->tmpl_param("javascript" => $IkiWiki::Plugin::toggle::javascript);
+ $form->tmpl_param("javascript" => IkiWiki::Plugin::toggle::include_javascript($params{page}, 1));
# Start with the attachments interface toggled invisible,
# but if it was used, keep it open.
if ($form->submitted ne "Upload Attachment" &&
@@ -279,7 +280,6 @@ sub attachment_list ($) { #{{{
link => htmllink($page, $page, $f, noimageinline => 1),
size => IkiWiki::Plugin::filecheck::humansize((stat(_))[7]),
mtime => displaytime($IkiWiki::pagemtime{$f}),
- mtime_raw => $IkiWiki::pagemtime{$f},
};
}
}
@@ -104,10 +105,10 @@ sub formbuilder_setup (@) { #{{{
$form->tmpl_param("field-upload" => '');
$form->tmpl_param("field-link" => '');
- # Add the javascript from the toggle plugin;
- # the attachments interface uses it to toggle visibility.
+ # Add the toggle javascript; the attachments interface uses
+ # it to toggle visibility.
require IkiWiki::Plugin::toggle;